@@ -1,8 +1,6 @@
 import pandas as pd
 import math
 import numpy as np
-import os
-os.chdir("C://Users//Jonny's PC//Documents//R FILES")
 
 class Node:
     def __init__(self):
@@ -112,8 +110,3 @@ def printTree(root: Node, depth=0):
         for child in root.children:
             printTree(child, depth + 1)
         n += 1
-        
-data = pd.read_csv("Price Discrimination - Wobi.csv")
-answerCol = "Bought"
-root = ID3(data, answerCol)
-printTree(root)
\ No newline at end of file
